@@ -3,7 +3,7 @@ package ObjectDB::DBHPool::Connection;
 use strict;
 use warnings;
 
-our $VERSION = '3.14';
+our $VERSION = '3.15';
 
 require Carp;
 use DBI;
@@ -20,6 +20,7 @@ sub new {
     $self->{username}      = $params{username};
     $self->{password}      = $params{password};
     $self->{attrs}         = $params{attrs};
+    $self->{do}            = $params{do};
 
     $self->{check_timeout} = 5 unless defined $self->{check_timeout};
     $self->{attrs} ||= {RaiseError => 1};
@@ -102,6 +103,12 @@ sub _get_dbh {
 
     Carp::croak("Can't connect $DBI::errstr") unless $dbh;
 
+    if ($self->{do}) {
+        foreach my $do (ref $self->{do} eq 'ARRAY' ? @{$self->{do}} : ($self->{do})) {
+            $dbh->do($do);
+        }
+    }
+
     return $dbh;
 }
 
